Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index a5bac543c528a352df3ee737d9dfb9efd61304c2..e0ea06486f009db8c9f96c541fbf6b3bf85fdcd4 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -3776,7 +3776,8 @@ class Map: public HeapObject { |
inline int visitor_id(); |
inline void set_visitor_id(int visitor_id); |
- // Returns the heap this map belongs to. |
+ // Returns the isolate/heap this map belongs to. |
+ inline Isolate* isolate(); |
inline Heap* heap(); |
typedef void (*TraverseCallback)(Map* map, void* data); |